#ifndef ClientApplication_h
#define ClientApplication_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "Config.h"
#include "CommandLineArguments.h"
#include "Counter.h"
#include "PixmapEngine.h"

#include <QSystemTrayIcon>

class ClientInterface;
class MainWindow;
class SystemNotifications;
class SystemTrayIcon;

namespace Ssh
{
    class Interface;
}

//* Main Window singleton object
class ClientApplication: public BaseApplication, public Counter
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    ClientApplication( CommandLineArguments );

    //* destructor
    virtual ~ClientApplication( void );

    //* create all widgets
    virtual bool realizeWidget( void );

    //*@name accessors
    //@{

    MainWindow& mainWindow( void ) const
    { return *mainWindow_; }

    QAction& mainWindowAction( void ) const
    { return *mainWindowAction_; }

    //@}

    //*@name application information
    //@{

    //* command line parser
    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const;

    //* usage
    void usage( void ) const;

    //* application name
    virtual QString applicationName( void ) const
    { return "Homechat"; }

    //* application icon
    virtual QIcon applicationIcon( void ) const
    {
        QIcon icon;
        icon.addPixmap( PixmapEngine::get( ":/homechat.png" ) );
        icon.addPixmap( PixmapEngine::get( ":/homechat-large.png" ) );
        return icon;
    }

    // application version
    virtual QString applicationVersion( void ) const
    { return VERSION; }

    // build time stamp
    virtual QString buildTimeStamp( void ) const
    { return BUILD_TIMESTAMP; }

    //@}

    protected Q_SLOTS:

    //* configuration
    virtual void _configuration( void );

    //* process request from application manager
    virtual bool _processCommand( Server::ServerCommand );

    private Q_SLOTS:

    //* configuration
    void _updateConfiguration( void );

    //* send notification
    void _notify( QString );

    //* system tray icon activated
    void _systemTrayActivated( QSystemTrayIcon::ActivationReason );

    //* toggle main window visibility
    void _toggleMainWindowVisibility( void );

    private:

    //* install actions
    void _installActions( void );

    //* main window visibility action
    QAction* mainWindowAction_ = nullptr;

    //* ssh connection
    Ssh::Interface* sshInterface_ = nullptr;

    //* communication interface
    ClientInterface* interface_ = nullptr;

    //* main window
    MainWindow* mainWindow_ = nullptr;

    //* system notifications
    bool useSystemNotifications_ = true;

    //* system notifications
    SystemNotifications* systemNotifications_ = nullptr;

    //* system tray icon
    SystemTrayIcon* systemTrayIcon_ = nullptr;

};

#endif
