/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectedClientsModel.h"
#include "Debug.h"
#include "IconEngine.h"
#include "IconNames.h"

#include <QPalette>

//_______________________________________________
const QString ConnectedClientsModel::columnTitles_[ ConnectedClientsModel::nColumns ] =
{
    tr( "People" )
};

//______________________________________________________________________
ConnectedClientsModel::ConnectedClientsModel( QObject* parent ):
    ListModel<ConnectionId>( parent ),
    Counter( "ConnectedClientsModel" )
{}

//______________________________________________________________________
QVariant ConnectedClientsModel::data( const QModelIndex& index, int role ) const
{

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated file info
    const ConnectionId& id( get()[index.row()] );

    // return text associated to file and column
    switch( role )
    {

        case Qt::DisplayRole:
        {
            switch( index.column() )
            {
                case Name: return id.userString();
                default: return QVariant();
            }
            break;
        }

        case Qt::DecorationRole:
        {
            switch( index.column() )
            {
                case Name: return icon( id.userState() );
                default: return QVariant();
            }
            break;
        }

        case Qt::ForegroundRole:
        {

            if( id.userState() == ConnectionId::Offline )
            {
                return QPalette().color( QPalette::Disabled, QPalette::Text );
            } else return QVariant();

        }

        default: return QVariant();

    }

    return QVariant();

}

//______________________________________________________________________
QVariant ConnectedClientsModel::headerData(int section, Qt::Orientation orientation, int role ) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//______________________________________________________________________
QIcon ConnectedClientsModel::icon( ConnectionId::UserState status ) const
{
    switch( status )
    {
        default:
        case ConnectionId::Online: return IconEngine::get( IconNames::UserOnline );
        case ConnectionId::Away:
        case ConnectionId::AwayForced: return IconEngine::get( IconNames::UserAway );
        case ConnectionId::Unavailable: return IconEngine::get( IconNames::UserBusy );
        case ConnectionId::Offline: return IconEngine::get( IconNames::UserOffline );
    }
}
