/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Color.h"
#include "HistoryMenu.h"
#include "IconSize.h"
#include "ServerInterface.h"
#include "Util.h"
#include "XmlOptions.h"

#include <QHostAddress>

//_____________________________________________________
//* Default options installer
void installDefaultOptions( void )
{
    // set options default values
    XmlOptions::get().setAutoDefault( true );

    XmlOptions::get().keep( "OPEN_LINK_APPLICATIONS" );

    // history
    XmlOptions::get().set( "DB_FILE", Option( File(".homechat-serverdb").addPath(Util::home()), Option::None ), true );
    XmlOptions::get().set<bool>( "COMPRESS_DB_FILE", true );

    // server connection
    XmlOptions::get().setRaw( "CHAT_HOST", QHostAddress( QHostAddress::LocalHost ).toString() );
    XmlOptions::get().set<int>( "CHAT_PORT", 2078 );

    // ssh tunnel connection
    XmlOptions::get().set<bool>( "USE_SSH", false );
    XmlOptions::get().set<bool>( "SSH_REMEMBER_PASSWORD", false );
    XmlOptions::get().setRaw( "SSH_USERNAME", Util::user() );
    XmlOptions::get().setRaw( "SSH_HOST", QHostAddress( QHostAddress::LocalHost ).toString() );
    XmlOptions::get().set<int>( "SSH_PORT", 22 );

    // flags
    XmlOptions::get().set<bool>( "USE_NOTIFICATIONS", true );
    XmlOptions::get().set<bool>( "USE_SYSTEMTRAY", true );
    XmlOptions::get().set<bool>( "START_HIDDEN", false );
    XmlOptions::get().set<bool>( "AUTO_CONNECT", true );

    // autosave
    XmlOptions::get().set<int>( "AUTHORIZATION_TIMEOUT", 2 );
    XmlOptions::get().set<int>( "PING_TIMEOUT", 1 );
    XmlOptions::get().set<int>( "AUTOSAVE_TIMEOUT", 1 );
    XmlOptions::get().set<int>( "IDLE_TIMEOUT", 10 );
    XmlOptions::get().set<int>( "CHECK_CONNECTIONS_TIMEOUT", 10 );

    // appearance
    XmlOptions::get().set<bool>( "SHOW_LINKS", true );
    XmlOptions::get().set<bool>( "USE_EMOTICONS", true );
    XmlOptions::get().set<int>( "EMOTICON_SIZE", 15 );
    XmlOptions::get().set<bool>( "SHOW_TOOLTIPS", true );
    XmlOptions::get().set<bool>( "SHOW_FETCH_PROGRESS", false );

    // history
    XmlOptions::get().set<int>( "DEFAULT_HISTORY_SPAN", HistoryMenu::OneDay );

    // log time span
    XmlOptions::get().set<int>( "LOG_SPAN", ServerInterface::Forever );

    // user colors
    XmlOptions::get().keep( "USER_COLOR" );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#2980B9" ) ) );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#14405C" ) ) );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#F67400" ) ) );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#DA4453" ) ) );

    XmlOptions::get().setAutoDefault( false );
}
