/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "HtmlHighlighter.h"
#include "Debug.h"

#include <QPalette>
#include <QStringList>
#include <QTextBlock>
#include <QUrl>
#include <QSet>

//________________________________________________________________________
HtmlHighlighter::HtmlHighlighter( QObject* parent ):
    QObject( parent ),
    Counter( "HtmlHighlighter" )
{
    Debug::Throw( "HtmlHighlighter::HtmlHighlighter.\n" );

    // regexp
    regexp_ = QRegExp( "(http(s{0,1})|file)\\://\\S+" );
}

//________________________________________________________________________
void HtmlHighlighter::process( QTextCursor cursor )
{

    Debug::Throw( "HtmlHighlighter::process.\n" );
    if( !enabled_ ) return;

    int position( 0 );
    QString text( cursor.block().text() );

    while( ( position = text.indexOf( regexp_, position ) ) >= 0 )
    {
        // find emoticon matching regexp
        const QString link( regexp_.cap(0) );
        const int length( link.size() );

        // set cursor at the right position
        cursor.movePosition( QTextCursor::StartOfBlock );
        cursor.movePosition( QTextCursor::Right, QTextCursor::MoveAnchor, position );
        cursor.movePosition( QTextCursor::Right, QTextCursor::KeepAnchor, length );

        // create relevant char format
        QTextCharFormat format;
        format.setFontUnderline( true );
        format.setForeground( QPalette().color( QPalette::Link ) );
        format.setAnchorHref( link );
        format.setAnchor( true );

        // apply to selection
        cursor.mergeCharFormat( format );

        // increment position
        position += length;

    }
}
