/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Menu.h"

#include "ClientApplication.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "MainWindow.h"
#include "Singleton.h"

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu" );

    // generic menu
    QMenu *menu;

    ClientApplication& application( *Singleton::get().application<ClientApplication>() );
    MainWindow& mainWindow( *static_cast<MainWindow*>( window() ) );

    // file menu
    menu = addMenu( tr( "File" ) );
    menu->addAction( &mainWindow.toggleConnectionAction() );
    menu->addAction( &application.closeAction() );

    // file menu
    menu = addMenu( tr( "Tools" ) );
    menu->addAction( &mainWindow.pingServerAction() );
    menu->addAction( &mainWindow.pingClientsAction() );
    menu->addSeparator();
    menu->addAction( &mainWindow.fetchConnectedClientsAction() );
    menu->addAction( &mainWindow.reloadAction() );

    // create Settings menu
    menu = addMenu( tr( "Settings" ) );
    menu->addAction( &application.configurationAction() );

    // create help menu
    menu = addMenu( tr( "Help" ) );
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

}
