/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MessageEditorWidget.h"

#include "BaseContextMenu.h"
#include "BaseIconNames.h"
#include "Debug.h"
#include "IconEngine.h"

//______________________________________________________
MessageEditorWidget::MessageEditorWidget( QWidget* parent ):
    LineEditor( parent )
{
    Debug::Throw( "MessageEditorWidget::MessageEditorWidget.\n" );
    _installActions();
}

//______________________________________________________________________________
void MessageEditorWidget::installContextMenuActions( BaseContextMenu* menu )
{

    Debug::Throw( "MessageEditorWidget::installContextMenuActions.\n" );

    // retrieve default context menu
    // second argument is to remove un-necessary actions
    LineEditor::installContextMenuActions( menu );

    // add specific actions
    menu->addSeparator();
    menu->addAction( removeMessageAction_ );
    menu->addAction( cancelMessageEditionAction_ );

    return;
}

//_________________________________________________
void MessageEditorWidget::_installActions( void )
{

    Debug::Throw( "MessageEditorWidget::_installActions.\n" );

    // remove message actions
    addAction( removeMessageAction_ = new QAction( IconEngine::get( IconNames::Cut ), tr( "Remove Message" ), this ) );
    removeMessageAction_->setShortcut( QKeySequence::Cut );

    // edit messsage actions
    addAction( cancelMessageEditionAction_ = new QAction( IconEngine::get( IconNames::DialogCancel ), tr( "Cancel Message Edition" ), this ) );

}
