/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ServerApplication.h"

#include "ServerInterface.h"
#include "XmlOptions.h"

#include <QApplication>

//____________________________________________
ServerApplication::ServerApplication( CommandLineArguments arguments ) :
    BaseCoreApplication( 0, arguments ),
    Counter( "Application" )
{}

//____________________________________________
ServerApplication::~ServerApplication( void ) = default;

//____________________________________________
bool ServerApplication::realizeWidget( void )
{
    Debug::Throw( "ServerApplication::realizeWidget.\n" );

    // check if the method has already been called.
    if( !BaseCoreApplication::realizeWidget() ) return false;

    // setup interface
    interface_ = new ServerInterface( this );
    interface_->initialize( commandLineParser( _arguments() ) );

    Debug::Throw( "ServerApplication::realizeWidget - done.\n" );
    return true;

}

//____________________________________________
CommandLineParser ServerApplication::commandLineParser( CommandLineArguments arguments, bool ignoreWarnings ) const
{
    Debug::Throw( "ServerApplication::commandLineParser.\n" );
    CommandLineParser out( BaseCoreApplication::commandLineParser() );
    out.setGroup( CommandLineParser::applicationGroupName );
    out.registerFlag( CommandLineParser::Tag( "--configure", "-c" ), tr( "start homechat-server configuration window" ) );
    out.registerFlag( CommandLineParser::Tag( "--message-list", "-m" ), tr( "show all saved chat messages" ) );
    out.registerOption( CommandLineParser::Tag( "--chat-host" ), tr( "string" ), tr( "use specified host for chat communication" ) );
    out.registerOption( "--chat-port", tr( "integer" ), tr( "use specified port for server communication" ) );
    if( !arguments.isEmpty() ) out.parse( arguments, ignoreWarnings );
    return out;

}

//____________________________________________
void ServerApplication::usage( void ) const
{
    _usage( "Homechat server" );
    commandLineParser().usage();
    return;
}
