#ifndef ServerApplication_h
#define ServerApplication_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseCoreApplication.h"
#include "Config.h"
#include "CommandLineArguments.h"
#include "Counter.h"

class ServerInterface;

//* Main Window singleton object
class ServerApplication: public BaseCoreApplication, public Counter
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    ServerApplication( CommandLineArguments );

    //* destructor
    virtual ~ServerApplication( void );

    //* create all widgets
    virtual bool realizeWidget( void );

    //*@name accessors
    //@{

    //* interface
    bool hasInterface( void ) const
    { return interface_; }

    //* interface
    ServerInterface& interface( void ) const
    { return *interface_; }

    //@}

    //*@name application information
    //@{

    //* command line parser
    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const;

    //* usage
    void usage( void ) const;

    //* application name
    virtual QString applicationName( void ) const
    { return "Homechat server"; }

    // application version
    virtual QString applicationVersion( void ) const
    { return VERSION; }

    // build time stamp
    virtual QString buildTimeStamp( void ) const
    { return BUILD_TIMESTAMP; }

    //@}

    private:

    //* interface
    ServerInterface* interface_ = nullptr;

};

#endif
