/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ServerConfigurationDialog.h"

#include "Debug.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "OptionComboBox.h"
#include "OptionSpinBox.h"
#include "OptionLineEditor.h"
#include "OptionBrowsedLineEditor.h"
#include "OptionCheckBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>
#include <QPushButton>

//_________________________________________________________
ServerConfigurationDialog::ServerConfigurationDialog( QWidget* parent ):
    BaseConfigurationDialog( parent )
{

    Debug::Throw( "ServerConfigurationDialog::ServerConfigurationDialog.\n" );
    setWindowTitle( tr( "Configuration - Homechat Server" ) );

    QWidget *box;
    OptionLineEditor* editor;
    OptionSpinBox* spinbox;
    OptionCheckBox* checkbox;


    {
        // server configuration
        QWidget* page = &addPage( IconEngine::get( IconNames::PreferencesServer ), tr( "Server" ), tr( "Server configuration" ) );
        page->layout()->addWidget( box = new QGroupBox( tr( "Connection Settings" ), page ) );
        GridLayout* gridLayout = new GridLayout();
        gridLayout->setMaxCount(2);
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->setLayout( gridLayout );

        QLabel* label;

        // host
        gridLayout->addWidget( label = new QLabel( tr( "Server host:" ), box ) );
        gridLayout->addWidget( editor = new OptionLineEditor( box, "CHAT_HOST" ) );
        label->setBuddy( editor );
        addOptionWidget( editor );

        // port
        gridLayout->addWidget( label = new QLabel( tr( "Server port:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "CHAT_PORT" ) );
        spinbox->setMinimum(0);
        spinbox->setMaximum(10000);
        label->setBuddy( spinbox );
        addOptionWidget( spinbox );

        page->layout()->addWidget( box = new QGroupBox( tr( "Message History" ), page ) );
        gridLayout = new GridLayout();
        gridLayout->setMaxCount(2);
        // gridLayout->setMargin(0);
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->setLayout( gridLayout );

        // autosave timeout
        gridLayout->addWidget( label = new QLabel( tr( "Autosave timeout:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "AUTOSAVE_TIMEOUT" ) );
        spinbox->setMinimum(0);
        spinbox->setMaximum(60);
        spinbox->setSuffix( tr("s") );
        spinbox->setSpecialValueText( tr( "Immediately" ) );
        label->setBuddy( spinbox );
        addOptionWidget( spinbox );

        OptionComboBox* comboBox;
        gridLayout->addWidget( label = new QLabel( tr( "Keep past messages for:" ), box ) );
        gridLayout->addWidget( comboBox = new OptionComboBox( box, "LOG_SPAN" ) );
        comboBox->setUseValue( false );

        // must be kept in sync with ServerInterface::TimeSpan enumeration
        comboBox->addItems( QStringList()
            << tr( "One Week" )
            << tr( "Two Weeks" )
            << tr( "On Month" )
            << tr( "Two Months" )
            << tr( "Six Months" )
            << tr( "One Year" )
            << tr( "Forever" ) );
        label->setBuddy( comboBox );
        addOptionWidget( comboBox );

        // output db file
        OptionBrowsedLineEditor* browseEditor;

        gridLayout->addWidget( label = new QLabel( tr( "Save past messages to:" ), box ) );
        gridLayout->addWidget( browseEditor = new OptionBrowsedLineEditor( box, "DB_FILE" ) );
        label->setBuddy( browseEditor );
        addOptionWidget( browseEditor );

        // compression
        gridLayout->increment();
        gridLayout->addWidget( checkbox = new OptionCheckBox( tr( "Compress message history" ), box, "COMPRESS_DB_FILE" ) );
        addOptionWidget( checkbox );

    }

    // load initial configuration
    read();

}
