/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SyntaxHighlighter.h"

#include "Color.h"
#include "Debug.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <QPalette>

//__________________________________________________________
SyntaxHighlighter::SyntaxHighlighter( QTextDocument* parent ):
    QSyntaxHighlighter( parent ),
    Counter( "SyntaxHighlighter" )
{
    Debug::Throw( "SyntaxHighlighter::SyntaxHighlighter.\n" );

    // regexp
    regexp_ = QRegExp( "^(\\[(?:\\d|:)*\\])\\s+(?:(?:\\.{3,3})|(\\S+:))" );

    // configuration
    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
    _updateConfiguration();

}

//__________________________________________________________
void SyntaxHighlighter::highlightBlock( const QString & text )
{

    if( !enabled_ ) return;

    if( text.indexOf( regexp_ ) < 0 ) return;

    if( !regexp_.cap(1).isEmpty() )
    {
        // highlight time
        const int position( regexp_.pos(1) );
        const int length( regexp_.cap(1).size() );
        QTextCharFormat format;
        format.setForeground( timeColor_ );
        setFormat( 0, position + length, format );
    }

    if( !regexp_.cap(2).isEmpty() && !colors_.isEmpty() )
    {
        const int position( regexp_.pos(2) );
        const int length( regexp_.cap(2).length() );
        QString user( regexp_.cap(2) );
        QColor color;
        if( !userMap_.contains( user ) )
        {

            // reset color index if needed
            if( colorIndex_ >= colors_.size() ) colorIndex_ = 0;
            color = colors_[colorIndex_];
            userMap_.insert( user, color );
            ++colorIndex_;

        } else color = userMap_[user];

        if( color.isValid() )
        {
            QTextCharFormat format;
            format.setForeground( color );
            setFormat( position, length, format );
        }

    }

}

//__________________________________________________________
void SyntaxHighlighter::_updateConfiguration( void )
{

    Debug::Throw( "SyntaxHighlighter::_updateConfiguration.\n" );

    // date color
    timeColor_ = QPalette().color( QPalette::Disabled, QPalette::Text );

    colors_.clear();
    foreach( const Option& color, XmlOptions::get().specialOptions( "USER_COLOR" ) )
    { colors_.append( color.get<Base::Color>() ); }

}
