#ifndef SystemTrayIcon_h
#define SystemTrayIcon_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ClientInterface.h"
#include "Debug.h"

#include <QSystemTrayIcon>
#include <QIcon>

class SystemTrayMenu;

//* application system tray icon
class SystemTrayIcon: public QSystemTrayIcon, public Counter
{

    Q_OBJECT;

    public:

    //* constructor
    SystemTrayIcon( QObject* parent = nullptr );

    //* destructor
    virtual ~SystemTrayIcon( void );

    public Q_SLOTS:

    //* update icon based on whether there are pending messages
    void updatePendingMessages( bool );

    //* update icon based on connection state
    void updateConnectionState( ClientInterface::State );

    protected Q_SLOTS:

    void _activated( QSystemTrayIcon::ActivationReason );

    private:

    //* show context menu
    void _showContextMenu( void ) const;

    //* connected icon
    QIcon connectedIcon_;

    //* disconnected icon
    QIcon disconnectedIcon_;

    //* pending messages icon
    QIcon pendingMessagesIcon_;

    //* menu
    SystemTrayMenu* contextMenu_ = nullptr;

};

#endif
