/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SystemTrayMenu.h"

#include "ClientApplication.h"
#include "Debug.h"
#include "MainWindow.h"
#include "Singleton.h"

//__________________________________________________
SystemTrayMenu::SystemTrayMenu( QWidget* parent ):
    QMenu( parent ),
    Counter( "SystemTrayMenu" )
{

    Debug::Throw( "SystemTrayMenu::SystemTrayMenu" );

    ClientApplication& application( *Singleton::get().application<ClientApplication>() );
    MainWindow& mainwindow( application.mainWindow() );

    setSeparatorsCollapsible( false );
    QAction* separator = addSeparator();
    separator->setText( application.applicationName() );
    separator->setIcon( application.applicationIcon() );

    // user state actions
    addActions( mainwindow.userStateActions().actions() );

    addSeparator();

    addAction( &application.configurationAction() );
    addSeparator();

    addAction( &application.aboutAction() );
    addAction( &application.aboutQtAction() );
    addSeparator();

    addAction( &mainwindow.toggleConnectionAction() );
    addAction( &application.mainWindowAction() );
    addAction( &application.closeAction() );

}
