/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ChatMessageListDialog.h"
#include "Debug.h"
#include "DefaultOptions.h"
#include "ServerApplication.h"
#include "ServerConfigurationDialog.h"
#include "Singleton.h"
#include "Util.h"

#include <QApplication>
#include <QCoreApplication>
#include <QString>

//__________________________________________
//* main function
int main (int argc, char *argv[])
{
    // options
    installDefaultOptions();

    // non recordable options
    XmlOptions::get().set( "RC_FILE", Option( File(".homechat-serverrc").addPath(Util::home()), Option::None ), true );
    XmlOptions::setFile( XmlOptions::get().raw( "RC_FILE" ) );
    XmlOptions::read();

    // debug level
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) Debug::Throw() << XmlOptions::get() << endl;

    // singleton application is deleted before QApplication
    const CommandLineArguments arguments( argc, argv );
    ServerApplication singleton( arguments );
    Singleton::get().setApplication( &singleton );

    if( singleton.commandLineParser( arguments ).hasFlag( "--configure" ) )
    {
        QTextStream( stdout ) << "running in configuration mode" << endl;

        // resources
        Q_INIT_RESOURCE( basePixmaps );
        Q_INIT_RESOURCE( pixmaps );

        // QCore application
        QApplication application( argc, argv );

        ServerConfigurationDialog dialog( nullptr );
        dialog.show();

        application.exec();
        return 0;
    } else if( singleton.commandLineParser( arguments ).hasFlag( "--message-list" ) ) {

        QTextStream( stdout ) << "running in message list edition mode" << endl;

        // resources
        Q_INIT_RESOURCE( basePixmaps );
        Q_INIT_RESOURCE( pixmaps );

        // QCore application
        QApplication application( argc, argv );

        ChatMessageListDialog dialog( nullptr );
        dialog.show();

        application.exec();
        return 0;

    } else {

        // QCore application
        QCoreApplication application( argc, argv );

        // initialize and run
        if( singleton.initApplicationManager() )
        {  application.exec(); }

    }

    return 0;

}
